@@ -229,10 +229,7 @@ class Simulation:
         """
         nc, ns, ec, ew, cmap = self.get_visual_settings(step)
 
-        if self.prm['edge_style'] == 'curved':
-            plt.gca().add_collection(LineCollection(curved_edges(self.graph, self.node_pos), linewidth=ew, color=ec))
-
-        elif self.prm['edge_style'] == 'bundled':
+        if self.prm['edge_style'] == 'bundled':
             plt.plot(self.edge_pos.x, self.edge_pos.y, zorder=1, linewidth=ew, color=ec)
 
         else:
